Documentation module
In here
In here you can find documentation on:
- The Template Directory Layout
- A migration guide to version 0.6
- The Configuration files:
templates.tomlthe Templates Manifestlanguages/manifest.tomlthe Language Manifestextra.tomlis fully defined by the template, it is not documented here
- A reference for writing templates
- A guide for developers on how to make the lib-humus parts of your application enjoyable for admins
See Also
Example code can be found in the lib-humus repository in the examples directory.
Modules
- admin_
experience - Admin Experience of lib-humus
- language_
manifest - Language Manifest
- migrating_
to_ 0_ 6 - Migrating to lib-humus 0.6
- template_
directory - Template Directory Layout
- templates_
manifest - Templates Manifest
- writing_
templates - Writing Templates