Module headers

Module headers 

This module contains structs for decoding HTTP headers that are not in the headers (via axum_extra) crate.

Structs

AcceptHeader
A parsed Accept header that can also be used as an optional axum extractor
AcceptLanguageHeader
A parsed Accept-Language header that can also be used as an optional axum extractor

Enums

AcceptHeaderItem
Part of the AcceptHeader
AcceptLanguageHeaderLanguage
Represents the two kinds of language identifies in an AcceptLanguageHeader.