TextFunction

Struct TextFunction 

pub struct TextFunction { /* private fields */ }
Tera template function that can localize a message. It contains an Arc shared reference of fluent bundle.

Usage assuming it was registered as text:

{{ text(id="hello-wold", lang="en", examplearg=foo, n=3, bla=true) }}

How types that will be handled:

  • null: will be ignored
  • string: will be passed to the fluent template as is
  • number: will be passed as is with default settings (for now), errors if the number isn’t representable as f64.
  • bool: will be passed as the strings true and false
  • object|array: will throw a type error

Implementations

Source

impl TextFunction

pub fn new( language_engine: Arc<LanguageEngine>, context_getter: TextFunctionContextGetter, ) -> Self

Create a new TextFunction using a LanguageEngine that can be shared between multiple data structures.

The language_getter is a callback that returns the language to use if the lang argument of the text function is not set. See TextFunctionContextGetter for a more detailed explanation.