pub struct TextFunctionContext {
pub language: Option<UnicodeLanguageIdentifier>,
pub escape_function: EscapeFn,
pub safe_suffix: Option<String>,
}Expand description
Localization context
Fields
language: Option<UnicodeLanguageIdentifier>The default language to use.
If None the text() function will try to read the language from its context or expect it being passed explicitly using the lang parameter.
escape_function: EscapeFnThe escape function to use for unsafe inputs
safe_suffix: Option<String>The suffix for safe message ids and arguments
Implementations
Sourceimpl TextFunctionContext
impl TextFunctionContext
Sourcepub fn matches_safe_suffix(&self, text: &str) -> bool
pub fn matches_safe_suffix(&self, text: &str) -> bool
Weather the given text matches the safe_suffix in this context.