pub struct TextFunctionError {
pub language: UnicodeLanguageIdentifier,
pub message_id: String,
pub kind: TextFunctionErrorKind,
}Expand description
Error that is returned when retrieving a translated text fails
Fields
language: UnicodeLanguageIdentifierThe language that was translated to while the error happened
message_id: StringThe message id the error happened for
kind: TextFunctionErrorKindThe kind of problem that occurred
Implementations
Sourceimpl TextFunctionError
impl TextFunctionError
Sourcepub fn new(
language: &UnicodeLanguageIdentifier,
message_id: &str,
kind: TextFunctionErrorKind,
) -> Self
pub fn new( language: &UnicodeLanguageIdentifier, message_id: &str, kind: TextFunctionErrorKind, ) -> Self
Convenience contructor to create a new TextFunctionError form borrowed values