UnicodeLanguageIdentifier

Struct UnicodeLanguageIdentifier 

pub struct UnicodeLanguageIdentifier(/* private fields */);
A wrapper for [unic_langid::LanguageIdentifier] that als implements serde traits.

Methods from Deref<Target = LanguageIdentifier>

pub fn matches<O>( &self, other: &O, self_as_range: bool, other_as_range: bool, ) -> bool

Compares a LanguageIdentifier to another AsRef<LanguageIdentifier allowing for either side to use the missing fields as wildcards.

This allows for matching between en (treated as en-*-*-*) and en-US.

Examples
use unic_langid_impl::LanguageIdentifier;

let li1: LanguageIdentifier = "en".parse()
    .expect("Parsing failed.");

let li2: LanguageIdentifier = "en-US".parse()
    .expect("Parsing failed.");

assert_ne!(li1, li2); // "en" != "en-US"
assert_ne!(li1.to_string(), li2.to_string()); // "en" != "en-US"

assert_eq!(li1.matches(&li2, false, false), false); // "en" != "en-US"
assert_eq!(li1.matches(&li2, true, false), true); // "en-*-*-*" == "en-US"
assert_eq!(li1.matches(&li2, false, true), false); // "en" != "en-*-US-*"
assert_eq!(li1.matches(&li2, true, true), true); // "en-*-*-*" == "en-*-US-*"
pub fn variants(&self) -> impl ExactSizeIterator

Returns a vector of variants subtags of the LanguageIdentifier.

Examples
use unic_langid_impl::LanguageIdentifier;

let li1: LanguageIdentifier = "ca-ES-valencia".parse()
    .expect("Parsing failed.");

assert_eq!(li1.variants().map(|v| v.as_str()).collect::<Vec<_>>(), &["valencia"]);

let li2: LanguageIdentifier = "de".parse()
    .expect("Parsing failed.");

assert_eq!(li2.variants().len(), 0);
pub fn set_variants(&mut self, variants: &[Variant])

Sets variant subtags of the LanguageIdentifier.

Examples
use unic_langid_impl::LanguageIdentifier;

let mut li: LanguageIdentifier = "ca-ES".parse()
    .expect("Parsing failed.");

li.set_variants(&["valencia".parse().expect("Parsing failed.")]);

assert_eq!(li.to_string(), "ca-ES-valencia");
pub fn has_variant(&self, variant: Variant) -> bool

Tests if a variant subtag is present in the LanguageIdentifier.

Examples
use unic_langid_impl::LanguageIdentifier;

let mut li: LanguageIdentifier = "ca-ES-macos".parse()
    .expect("Parsing failed.");

assert_eq!(li.has_variant("valencia".parse().unwrap()), false);
assert_eq!(li.has_variant("macos".parse().unwrap()), true);
pub fn clear_variants(&mut self)

Clears variant subtags of the LanguageIdentifier.

Examples
use unic_langid_impl::LanguageIdentifier;

let mut li: LanguageIdentifier = "ca-ES-valencia".parse()
    .expect("Parsing failed.");

li.clear_variants();

assert_eq!(li.to_string(), "ca-ES");
pub fn character_direction(&self) -> CharacterDirection

Returns character direction of the LanguageIdentifier.

Examples
use unic_langid_impl::{LanguageIdentifier, CharacterDirection};

let li1: LanguageIdentifier = "es-AR".parse()
    .expect("Parsing failed.");
let li2: LanguageIdentifier = "fa".parse()
    .expect("Parsing failed.");

assert_eq!(li1.character_direction(), CharacterDirection::LTR);
assert_eq!(li2.character_direction(), CharacterDirection::RTL);