TextFunctionContextGetter

Type Alias TextFunctionContextGetter 

pub type TextFunctionContextGetter = fn(args: &Kwargs, state: &State<'_>) -> TeraResult<TextFunctionContext>;
Callback type that returns the TextFunctionContext to use for the text() template function. This is intended to provide an implicit default language and settings for the safe_suffix feature. This function may use the template context or a global context (make sure your invariants hold in that case!).