pub struct TemplateSetting {
pub language: Option<UnicodeLanguageIdentifier>,
pub format: HumusFormatIdentifier,
}Expand description
Language and format setting for the template
It is added as an extension to the request by the TemplateSettingsLayer.
When using axum you can retrieve it using:
ⓘ
async fn some_handler(
// … other arguments …,
Extension(settings): Extension<TemplateSetting>,
) -> Response {
// TODO
}Fields
language: Option<UnicodeLanguageIdentifier>The language to use for the template, None means that no preference could be extracted and that the backend should use the default languge.
format: HumusFormatIdentifierThe format identifier for giving to the templating engine.