pub struct TemplateSettingsService<S> { /* private fields */ }Expand description
Service created by the TemplateSettingsLayer (you probably want to construct the layer)
It extracts language information and provides the TemplateSetting extension for every request that passes through it.
Language information is sourced from two places:
- The
lib_humus_languagecookie which may contain UnicodeLanguageIdentifier - The
Accept-Languageheader where it uses the first language that is also present in the language manifest.
Format information is sources from:
- The
formatparameter, this is not validated here as validation is left to the templating engine - The
Acceptheader using information from the templates manifest