pub enum TemplatingEngineLoaderError {
ConfigurationError(HumusConfigError),
TemplatesManifestError(HumusConfigError),
TemplatesManifestProblems(Vec<TemplatesManifestProblem>),
TemplateDirectoryNotFound {
path: PathBuf,
},
TemplateDirectoryIoError {
path: PathBuf,
error: Error,
},
TemplateParseError {
path: PathBuf,
format: HumusFormatIdentifier,
tera_error: Error,
},
}Expand description
Returned when a TemplatingEngine fails to initalize.
Variants
ConfigurationError(HumusConfigError)
An error occourred while loading the template configuration file.
TemplatesManifestError(HumusConfigError)
An error occurred while loading the template manifest file.
TemplatesManifestProblems(Vec<TemplatesManifestProblem>)
One or more problems were found in the templates manifest file.
TemplateDirectoryNotFound
No template directory at.
TemplateDirectoryIoError
There was an error reading the template directory
TemplateParseError
An error occourred while parsing the templates.