pub struct FormatDescription {
pub media_type: MediaType,
pub extension: String,
pub additional_templates: Vec<String>,
}Expand description
Describes a single template format that can be rendered to.
Fields
media_type: MediaTypeThe media type that the server should serve the output of this template as.
extension: StringThe file extension that the template files use without a leading dot.
Example: if your template file is named index.html set html here.
additional_templates: Vec<String>Full filename of additional templates to load