This module contains structs for decoding HTTP headers that are not in the headers (via axum_extra) crate.
Structs
- Accept
Header - A parsed
Acceptheader that can also be used as an optional axum extractor - Accept
Language Header - A parsed
Accept-Languageheader that can also be used as an optional axum extractor
Enums
- Accept
Header Item - Part of the AcceptHeader
- Accept
Language Header Language - Represents the two kinds of language identifies in an AcceptLanguageHeader.